Machine name
Color tag

Binding
TCP UNIX

Authentication provider
Sudo

SSL
SSL certificate file
Generate a self-signed certificate

SSL client authentication
SSL client certificates
No certificates are created yet.

#### {{certificate.user}}

`{{certificate.digest}}`

New certificate

#### New client certificate

#### Generating certificate

This might take a few seconds
Download certificate
Login as
Country
State
Organization
Common name

E-mail authentication
Allows login with a confirmed e-mail address via Mozilla Persona auth service. Requires server-side internet access.
No e-mail addresses added yet.

#### {{email}}

{{username}}

New address

#### New e-mail address

E-mail address
User to log in
Save Restart panel